==> check-mk_1.2.6p12.orig.tar.gz: check_mk-oracle_dataguard_stats.php <==
<?php
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# This file is part of Check_MK.
# The official homepage is at http://mathias-kettner.de/check_mk.
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# ails.  You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

$servicename_parts = explode("_", $servicedesc);
$oracle_sid = $servicename_parts[1];

$opt[1] = "--vertical-label 'apply Lag (s)' -l0 --title \"Dataguard Stats of $oracle_sid\" ";

$def[1] = "DEF:sec=$RRDFILE[1]:$DS[1]:MAX ";
$def[1] .= "CDEF:apply_lag=sec,1,/ ";
$def[1] .= "AREA:apply_lag#80f000:\"Apply Lag (s)\" ";
$def[1] .= "LINE:apply_lag#408000 ";
$def[1] .= "GPRINT:apply_lag:LAST:\"%7.2lf %s LAST\" ";
$def[1] .= "GPRINT:apply_lag:MAX:\"%7.2lf %s MAX\" ";
?>

==> check-mk_1.2.8p16.orig.tar.gz: check_mk-oracle_dataguard_stats.php <==
<?php
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# This file is part of Check_MK.
# The official homepage is at http://mathias-kettner.de/check_mk.
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

$servicename_parts = explode("_", $servicedesc);
$oracle_sid = $servicename_parts[1];

$opt[1] = "--vertical-label 'apply Lag (s)' -l0 --title \"Dataguard Stats of $oracle_sid\" ";

$def[1] = "DEF:sec=$RRDFILE[1]:$DS[1]:MAX ";
$def[1] .= "CDEF:apply_lag=sec,1,/ ";
$def[1] .= "AREA:apply_lag#80f000:\"Apply Lag (s)\" ";
$def[1] .= "LINE:apply_lag#408000 ";
$def[1] .= "GPRINT:apply_lag:LAST:\"%7.2lf %s LAST\" ";
$def[1] .= "GPRINT:apply_lag:MAX:\"%7.2lf %s MAX\" ";
?>
